clear all ; clc ; close all ; 

set(0,'defaultAxesFontSize',12);
set(0,'defaultAxesFontName','century');
set(0,'defaultTextFontSize',12);
set(0,'defaultTextFontName','century');

year = 1960:2021;

%% load excel file
num_RealGDP = xlsread('OECD_economicoutlook\RealGDP.xls','E7:BN43');
num_RealCons = xlsread('OECD_economicoutlook\RealCons.xls','E7:BN43');
num_RealInv = xlsread('OECD_economicoutlook\RealInv.xls','D7:BM23');
num_Population = xlsread('OECD_economicoutlook\Population.xls','E7:BN43'); 
num_Longtermint = xlsread('OECD_economicoutlook\Longtermint.xls','E7:BN42');
num_Shorttermint = xlsread('OECD_economicoutlook\Shorttermint.xls','E7:BN43');
num_NetDebt = xlsread('OECD_economicoutlook\NetDebt.xls','E7:BN38');
num_GrossDebt = xlsread('OECD_economicoutlook\GrossDebt.xls','E7:BN40');
num_NetLending = xlsread('OECD_economicoutlook\NetLending.xls','E7:BN40');

%% population extrapolation using the mean of the growth rate in the recent three years 
%{
for i=1:36
    adnan = max(find( num_Population(i,:) > 0)) + 1;
    for j = adnan:size(year,2)
        g =  (num_Population(i,j-1)/num_Population(i,j-4))^(1/3);
        num_Population(i,j) = num_Population(i,j-1) * g;
    end
end
%}

%% initial setting for the address & start data of collapse in each country

title_country = {'Japan', 'US', 'Euro 17', 'Italy', 'France'};
fileID = fopen('summary.txt','w+');
fprintf(fileID, '  i \t  mu \t   g \t s(dY) \t s(dC) \t s(dI) \t Cor(dY,B/Y) \t s(dI,B/Y) \n');
lag = 15;

for i=1:4
  
ad_year = 2007-1960+1;
    
if i == 1 % Japan
    ad_GDP = 24-7+1; 
    ad_Inv = 15-7+1;
    ad_Pop = 24-7+1;
    ad_Longtermint = 23-7+1;
    ad_Shorttermint = 24-7+1;
    ad_NetDebt = 22-7+1;
    ad_GrossDebt = 23-7+1;
    ad_year = 1990-1960+1;
elseif i == 2 % US
    ad_GDP = 42-7+1; 
    ad_Inv = 22-7+1;
    ad_Pop = 42-7+1;
    ad_Longtermint = 41-7+1;
    ad_Shorttermint = 42-7+1;
    ad_NetDebt = 37-7+1;
    ad_GrossDebt = 39-7+1;
elseif i == 3 % Euro 17
    ad_GDP = 43-7+1; 
    ad_Inv = 0; % no data
    ad_Pop = [8 9 14 15 16 17 18 21 23 28 30 34 35 36 37]-7+1; % sum of 15 countries (no data for Cyprus (CY) and Malta (MT) )
    ad_Pop = [8 9 14 15 16 17 21 23 28 30 34 36 37]-7+1; % exclude Greece/Slovakia because of no data in 1991; sum of 15 countries (no data for Cyprus (CY) and Malta (MT) )
    %{
    EA-11 (1 January 1999 - 31 December 2000):
    Austria (AT), Belgium (BE), Finland (FI), France (FR), Germany (DE), Ireland (IE), Italy (IT), Luxembourg (LU), Netherlands (NL), Portugal (PT), Spain (ES) 
    EA-12 (1 January 2001 - 31 December 2006):
    EA-11 + Greece (EL) 
    EA-13 (1 January 2007 - 31 December 2007):
    EA-12 + Slovenia (SI) 
    EA-15 (1 January 2008 - 31 December 2008):
    EA-13 + Cyprus (CY) and Malta (MT) 
    EA-17  + Slovakia (SK) Estonia (EE) 
    %}
    ad_Longtermint = 42-7+1;
    ad_Shorttermint = 43-7+1;
    ad_NetDebt = 38-7+1;
    ad_GrossDebt = 40-7+1;
elseif i == 4 % Italy
    ad_GDP = 23-7+1; 
    ad_Inv = 0; % no data
    ad_Pop = 23-7+1;
    ad_Longtermint = 22-7+1;
    ad_Shorttermint = 23-7+1;
    ad_NetDebt = 21-7+1;
    ad_GrossDebt = 22-7+1;
elseif i == 5 % France
    ad_GDP = 16-7+1; 
    ad_Inv = 12-7+1;
    ad_Pop = 16-7+1;
    ad_Longtermint = 15-7+1;
    ad_Shorttermint = 16-7+1;
    ad_NetDebt = 15-7+1;
    ad_GrossDebt = 15-7+1;

end


if size(ad_Pop,2) > 1
    Pop = sum(num_Population(ad_Pop,:), 1);
else
    Pop = num_Population(ad_Pop,:);
end

Y = log( num_RealGDP(ad_GDP,:)./Pop );
Y0 = Y(1,ad_year-lag);
Y = Y(1,ad_year-lag:end) - Y0; % base year: lag years before
%mu =  ( Y(1,ad_year) - Y(1,ad_year-lag) )*(1/lag); % average growth rate in the last lag years
mu2 =  ( Y(1,end) - Y(1,1) )*(1/( size(Y,2) )); % average growth rate in the sample years
x = 1:size( Y,2);
x = x';
X = [ones(length(x),1) x];
b = X\Y';
Y_hypo = (X*b)';
%Y_hypo = zeros(1,size(year,2));
%Y_hypo(1,1:ad_year) = Y(1, 1:ad_year);
%for j = (ad_year+1):size(year,2)
%    Y_hypo(1,j) = Y_hypo(1,j-1) + mu;
%end

C = log( num_RealCons(ad_GDP,:)./Pop );
%C = C(1,ad_year-lag:end) - C(1,41);
C = C(1,ad_year-lag:end) - Y0;

if ad_Inv > 0
    I = log( num_RealInv(ad_Inv,:)./Pop );
    %I = I(1,ad_year-lag:end) - I(1,41);
    I = I(1,ad_year-lag:end) - Y0;
else
    I = NaN*ones(1,size(Y,2));
end

Bnet = [NaN num_NetDebt(ad_NetDebt,1:end-1)]/100; % beginning of each year % net debt
Bgro = [NaN num_GrossDebt(ad_GrossDebt,1:end-1)]/100; % beginning of each year % gross debt
G = -num_NetLending(ad_GrossDebt,:)/100; % minus primary balance (equal to g in the model)
Longtermint = num_Longtermint(ad_Longtermint,:)/100;
Shorttermint = num_Shorttermint(ad_Shorttermint,:)/100;

XConst = [ones(length(x),1)];
if i==1
    C0 = C-Y_hypo;       % common trend with Y
    I0 = I-Y_hypo;       % common trend with Y
    b = XConst\C0';
    C0_hypo = (XConst*b)';
    b = XConst\I0';
    I0_hypo = (XConst*b)';
    
    %b = X\C';          % seperate trend from Y
    %C_hypo = (X*b)';   % seperate trend from Y
    %b = X\I';
    %I_hypo = (X*b)';
    
    Y_tab = [year(ad_year-lag:end); Y; Y-Y_hypo];
    C_tab = [year(ad_year-lag:end); C; C0-C0_hypo]; 
    I_tab = [year(ad_year-lag:end); I; I0-I0_hypo]; 
    B_Y_tab = [year(ad_year-lag:end); Bnet(ad_year-lag:end); Bgro(ad_year-lag:end)]; 
    save data_japan.mat Y_tab C_tab I_tab B_Y_tab;
end

if i==2
    C0 = C-Y_hypo;       % common trend with Y
    I0 = I-Y_hypo;       % common trend with Y
    b = XConst\C0';
    C0_hypo = (XConst*b)';
    b = XConst\I0';
    I0_hypo = (XConst*b)';
    
    %b = X\C';          % seperate trend from Y
    %C_hypo = (X*b)';   % seperate trend from Y
    %b = X\I';
    %I_hypo = (X*b)';
    
    Y_tab = [year(ad_year-lag:end); Y; Y-Y_hypo];
    C_tab = [year(ad_year-lag:end); C; C0-C0_hypo]; 
    I_tab = [year(ad_year-lag:end); I; I0-I0_hypo]; 
    B_Y_tab = [year(ad_year-lag:end); Bnet(ad_year-lag:end); Bgro(ad_year-lag:end)]; 
    save data_us.mat Y_tab C_tab I_tab B_Y_tab;
end


figure(1)
subplot(2,2,i)
hold off
yyaxis left
h(1) = plot(year(ad_year-lag:end-2), Y(1:end-2), 'k-', 'LineWidth', 2);
hold on
h(2) = plot(year(ad_year-lag:end-2), Y_hypo(1:end-2));
h(3) = plot([year(ad_year) year(ad_year)], [-0.5 max(Y_hypo)+0.5], '--' );
if i==1
    ylim([0 1]);
else
    ylim([-0.1 0.5]);
end
yyaxis right
h(4) = plot(year(ad_year-lag:end-2), Bnet(ad_year-lag:end-2), 'bo-', 'LineWidth', 1);
hold on
h(5) = plot(year(ad_year-lag:end-2), Bgro(ad_year-lag:end-2), 'rx-', 'LineWidth', 1);
if i==1
    ylim([0 3]);
else
    ylim([0 2]);
end
ax = gca;
ax.YAxis(1).Color = 'black';
ax.YAxis(2).Color = 'black';
title(title_country(i));
if i == 1
    %legend('Location','northwest')
    legend(h([1, 4, 5]), 'Y (left)', 'B^G/Y (net, right)', 'B^G/Y (gross, right)' )
    legend('boxoff')
end

figure(2)
subplot(2,2,i)
hold off
yyaxis left
h(1) = plot(year(ad_year-lag:end), Longtermint(ad_year-lag:end), 'k-', 'LineWidth',1);
hold on
h(2) = plot(year(ad_year-lag:end), Longtermint(ad_year-lag:end)-Shorttermint(ad_year-lag:end) , 'k-', 'LineWidth',2);
h(3) = plot([year(ad_year) year(ad_year)], [-0.05 0.15], '--' );
plot([year(ad_year-lag) year(end)], [0. 0], 'k--' );
ylim([-0.05 0.10]);
yyaxis right
h(4) = plot(year(ad_year-lag:end), Bnet(ad_year-lag:end), 'bo-');
ylim([0 1.5]);
ax = gca;
ax.YAxis(1).Color = 'black';
ax.YAxis(2).Color = 'black';
title(title_country(i));
if i == 1
    %legend('Location','northwest')
    legend(h([1,2, 4]), 'Long-term interest rate (left)', 'Long minus short-term interest rate (left)', 'B^G/Y (net, right)' )
    legend('boxoff')
end

% save data
dY = Y(2:end-2) - Y(1:end-3);
dC = C(2:end-2) - C(1:end-3);
dI = I(2:end-2) - I(1:end-3);
ysigma = nanstd( dY );
csigma = nanstd( dC );
isigma = nanstd( dI );
ybcor = corrcoef(dY', Bnet(ad_year-lag+1:end-2)', 'rows','complete'); % correlation between dY and B^G/Y
ibcor = corrcoef(dI', Bnet(ad_year-lag+1:end-2)', 'rows','complete'); % correlation between dI and B^G/Y
fprintf(fileID, '%2.0f \t  %6.4f  \t  %6.4f \t  %6.4f \t  %6.4f \t  %6.4f \t  %6.4f \t  %6.4f \n', i, mu2, nanmean(G), ysigma, csigma, isigma, ybcor(1,2), ibcor(1,2));

end

fclose(fileID);



