
function [f V] = function_main_EZnew(coeffs_all, boundREAL1, boundREAL2, nodes_k, nodes_b, bound1, bound2, P, DF, DF2)


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% this function evalutes the errors in the FOCs
%%% then we try to set this function equal to zero
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

ncheb = P.ncheb;
Neps = P.Neps;

if P.normal_tax == 1
    
    [f V] = function_main_EZnew_ctax(coeffs_all, boundREAL1, boundREAL2, nodes_k, nodes_b, bound1, bound2, P, DF, DF2);
    
else
    
    %%% note: the following global variables can also be passed around as an
    %%% argument (this is necessary to use parfor)
    coeffs_N   = coeffs_all(1:ncheb*ncheb) ;
    coeffs_Nd   = coeffs_all(ncheb*ncheb+1:2*ncheb*ncheb) ; %disaster
    coeffs_C   = coeffs_all(2*ncheb*ncheb+1:3*ncheb*ncheb) ;
    coeffs_Cd   = coeffs_all(3*ncheb*ncheb+1:4*ncheb*ncheb) ;
    coeffs_U   = coeffs_all(4*ncheb*ncheb+1:5*ncheb*ncheb) ; 
    coeffs_Ud   = coeffs_all(5*ncheb*ncheb+1:6*ncheb*ncheb) ; 
    coeffs_QG   = coeffs_all(6*ncheb*ncheb+1:7*ncheb*ncheb) ; % government bond price
    coeffs_QGd   = coeffs_all(7*ncheb*ncheb+1:8*ncheb*ncheb) ; % government bond price
    coeffs_lambda   = coeffs_all(8*ncheb*ncheb+1:9*ncheb*ncheb) ; % inefficiency of capital use by HH in production

    coeffs_N   = reshape(coeffs_N,[ncheb ncheb]) ;
    coeffs_C   = reshape(coeffs_C,[ncheb ncheb]) ;
    coeffs_U   = reshape(coeffs_U,[ncheb ncheb]) ;
    coeffs_QG   = reshape(coeffs_QG,[ncheb ncheb]) ;
    coeffs_Nd   = reshape(coeffs_Nd,[ncheb ncheb]) ;
    coeffs_Cd   = reshape(coeffs_Cd,[ncheb ncheb]) ;
    coeffs_Ud   = reshape(coeffs_Ud,[ncheb ncheb]) ;
    coeffs_QGd   = reshape(coeffs_QGd,[ncheb ncheb]) ;
    coeffs_lambda = reshape(coeffs_lambda,[ncheb ncheb]) ;

%%% construct values of N,C,L, etc. at chebychev nodes

currentN   = zeros(ncheb,ncheb);
currentC   = zeros(ncheb,ncheb);
currentU   = zeros(ncheb,ncheb);
currentK   = zeros(ncheb,ncheb);
currentB   = zeros(ncheb,ncheb);
currentQG   = zeros(ncheb,ncheb);
currentNd = currentN;
currentCd = currentC;
currentUd = currentU;
currentKd = currentK;
currentBd = currentB;
currentQGd = currentQG;
currentlambda  = zeros(ncheb,ncheb);

for i=1:ncheb
    for j=1:ncheb
        currentK(i,j)   = nodes_k(i) ;
        currentB(i,j)   = nodes_b(j) ;
        currentN(i,j)   = chebeval2(coeffs_N,nodes_k(i),nodes_b(j),bound1,bound2,ncheb) ;
        currentC(i,j)   = chebeval2(coeffs_C,nodes_k(i),nodes_b(j),bound1,bound2,ncheb) ;
        currentU(i,j)   = chebeval2(coeffs_U,nodes_k(i),nodes_b(j),bound1,bound2,ncheb) ;
        currentQG(i,j)   = chebeval2(coeffs_QG,nodes_k(i),nodes_b(j),bound1,bound2,ncheb) ; 
        currentNd(i,j)   = chebeval2(coeffs_Nd,nodes_k(i),nodes_b(j),bound1,bound2,ncheb) ;
        currentCd(i,j)   = chebeval2(coeffs_Cd,nodes_k(i),nodes_b(j),bound1,bound2,ncheb) ;
        currentUd(i,j)   = chebeval2(coeffs_Ud,nodes_k(i),nodes_b(j),bound1,bound2,ncheb) ;
        currentQGd(i,j)   = chebeval2(coeffs_QGd,nodes_k(i),nodes_b(j),bound1,bound2,ncheb) ; 
        currentlambda(i,j)   = chebeval2(coeffs_lambda,nodes_k(i),nodes_b(j),bound1,bound2,ncheb) ; 
    end
end

currentN0 = currentN;
currentNd0 = currentNd;
currentC0 = currentC;
currentCd0 = currentCd;
if P.nonnegativity==1
    currentN  = max(min(currentN,.999),1e-8) ;
    currentNd  = max(min(currentNd,.999),1e-8) ;
    currentC  = max(currentC,1e-8) ;
    currentCd  = max(currentCd,1e-8) ;
    currentlambda = max(min(currentlambda,1),0) ; 
end

if P.lambdaD == 0
    currentlambdaD = currentlambda;
else
    currentlambdaD = P.lambdaD;
end


currentW = (1-P.alpha).*currentK.^P.alpha.*currentN.^(-P.alpha) ;
currentY  = currentK.^P.alpha.*currentN.^(1-P.alpha) ;
currentI = currentY - currentC ;
currentWd = (1-P.alpha).*(currentlambda.*currentK).^P.alpha.*currentNd.^(-P.alpha) ;
currentYd  = (currentlambda.*currentK).^P.alpha.*currentNd.^(1-P.alpha) ;
currentId = currentYd - currentCd ;
currentI0 = currentI;
currentId0 = currentId;
if P.nonnegativity==1  % investment has to be positive
    currentI = max(1e-8, currentI);
    currentId = max(1e-8, currentId);
    currentC = currentY - currentI;
    currentCd = currentYd - currentId;
end

% current tax in disaster
currentTauCd = P.omega(2)*(currentB+P.g)./currentCd; 

%%% 1st FOC: error in FOC for labor:
part1 = currentW.*(1-currentN)-(1-P.nu)/P.nu*currentC ;
part1 = part1 + (currentN-currentN0).*(currentN-currentN0) + (currentC-currentC0).*(currentC-currentC0);
part11 = reshape(part1,ncheb*ncheb,1) ;
part1d = currentWd.*(1-currentNd)-(1-P.nu)/P.nu*currentCd.*(1+currentTauCd) ;
part1d = part1d + (currentNd-currentNd0).*(currentNd-currentNd0) + (currentCd-currentCd0).*(currentCd-currentCd0);
part11d = reshape(part1d,ncheb*ncheb,1) ;

%%% for the other FOCs, need to know future values:
phiADJ = P.a_0 + P.a_1./(1-P.eta).*(currentI./currentK).^(1-P.eta); % the last part of this can create non-real number
phiprimetoday = P.a_1.*(currentI./currentK).^(-P.eta);
phiADJd = P.a_0 + P.a_1./(1-P.eta).*(currentId./currentK).^(1-P.eta); % the last part of this can create non-real number
phiprimetodayd = P.a_1.*(currentId./currentK).^(-P.eta);

%%%%%%%%%%%%%%%%%%%%%% capital next period, (d for when disaster hits today,) if today in (ncheb,ncheb) and get tomorrow eps
%%% gov bond next period, (d for when disaster hits today,) if today in (ncheb,ncheb) and get tomorrow eps
Kprime = zeros(ncheb,ncheb,Neps);
Bprime = zeros(ncheb,ncheb,Neps);
Kprimed = zeros(ncheb,ncheb,Neps);
Bprimed = zeros(ncheb,ncheb,Neps);
for i=1:Neps
    Kprime(:,:,i) =  max(boundREAL1(1),min( ((1-P.delta).*currentK+phiADJ.*currentK)/(exp(P.mu+P.stdtfp*P.grideps(i))),boundREAL1(2)));
    bprime = (currentB + P.g)./currentQG;
    Bprime(:,:,i) =  max(boundREAL2(1),min( bprime/exp(P.mu+P.stdtfp*P.grideps(i)) , boundREAL2(2)));
    bprimed = (currentB + P.g)*(1-sum(P.omega))./currentQGd;
    Kprimed(:,:,i) =  max(boundREAL1(1),min( ((1-P.delta).*currentlambdaD.*currentK+phiADJd.*currentK)/(exp(P.mu+P.stdtfp*P.grideps(i))),boundREAL1(2)));
    Bprimed(:,:,i) =  max(boundREAL2(1),min( bprimed/exp(P.mu+P.stdtfp*P.grideps(i)) , boundREAL2(2))); 
end

%%%%%%%%%%%%%%%%%%%
%%% Second FOC %%%

futureN00 = chebeval2(coeffs_N,Kprime,Bprime,bound1,bound2,ncheb) ; %no disaster in t & t+1
futureC00 = chebeval2(coeffs_C,Kprime,Bprime,bound1,bound2,ncheb) ;
futureU00 = chebeval2(coeffs_U,Kprime,Bprime,bound1,bound2,ncheb) ;
futureN0d = chebeval2(coeffs_Nd,Kprime,Bprime,bound1,bound2,ncheb) ; % no in t & disaster in t+1
futureC0d = chebeval2(coeffs_Cd,Kprime,Bprime,bound1,bound2,ncheb) ;
futureU0d = chebeval2(coeffs_Ud,Kprime,Bprime,bound1,bound2,ncheb) ;
futurelambda0 = chebeval2(coeffs_lambda,Kprime,Bprime,bound1,bound2,ncheb) ;
futureNd0 = chebeval2(coeffs_N,Kprimed,Bprimed,bound1,bound2,ncheb) ; % disaster in t & no in t+1
futureCd0 = chebeval2(coeffs_C,Kprimed,Bprimed,bound1,bound2,ncheb) ;
futureUd0 = chebeval2(coeffs_U,Kprimed,Bprimed,bound1,bound2,ncheb) ;
futureNdd = chebeval2(coeffs_Nd,Kprimed,Bprimed,bound1,bound2,ncheb) ; % disaster in t & t+1
futureCdd = chebeval2(coeffs_Cd,Kprimed,Bprimed,bound1,bound2,ncheb) ;
futureUdd = chebeval2(coeffs_Ud,Kprimed,Bprimed,bound1,bound2,ncheb) ;
futurelambdad = chebeval2(coeffs_lambda,Kprimed,Bprimed,bound1,bound2,ncheb) ;

if P.nonnegativity==1
    futureU00 = max(futureU00,1e-13) ;
    futureU0d = max(futureU0d,1e-13) ;
    futureUd0 = max(futureUd0,1e-13) ;
    futureUdd = max(futureUdd,1e-13) ;
    futureN00  = max(min(futureN00,.999),1e-6) ;
    futureN0d  = max(min(futureN0d,.999),1e-6) ;
    futureNd0  = max(min(futureNd0,.999),1e-6) ;
    futureNdd  = max(min(futureNdd,.999),1e-6) ;
    futurelambda0 = max(min(futurelambda0,1),0) ;
    futurelambdad = max(min(futurelambdad,1),0) ;
end
if P.lambdaD == 0
    futurelambdaD0 = futurelambda0;
    futurelambdaDd = futurelambdad;
else
    futurelambdaD0 = P.lambdaD;
    futurelambdaDd = P.lambdaD;
end
%norm_fac = 1 ;  % mean(futureU(:)) ;
%futureU = futureU/norm_fac ;
%futureUd = futureUd/norm_fac ;

futureY00 = Kprime.^P.alpha.*futureN00.^(1-P.alpha) ;
if P.nonnegativity==1
    futureC00 = min(futureY00*.999,max(futureC00,1e-6)) ;  % investment has to be above zero
end
futureI00 = futureY00 - futureC00 ;

futureY0d = (futurelambda0.*Kprime).^P.alpha.*futureN0d.^(1-P.alpha) ;
if P.nonnegativity==1
    futureC0d = min(futureY0d*.999,max(futureC0d,1e-6)) ;
end
futureI0d = futureY0d - futureC0d ;

futureYd0 = Kprimed.^P.alpha.*futureNd0.^(1-P.alpha) ;
if P.nonnegativity==1
    futureCd0 = min(futureYd0*.999,max(futureCd0,1e-6)) ;
end
futureId0 = futureYd0 - futureCd0 ;

futureYdd = (futurelambdad.*Kprimed).^P.alpha.*futureNdd.^(1-P.alpha) ;
if P.nonnegativity==1
    futureCdd = min(futureYdd*.999,max(futureCdd,1e-6)) ;
end
futureIdd = futureYdd - futureCdd ;

futurePHI00 =  P.alpha*futureY00./Kprime + (1 - P.delta) ;  % R^K(t+1)
futurePHI0d =  P.alpha*futureY0d./Kprime + (1 - P.delta).*futurelambdaD0 ;
futurePHId0 =  P.alpha*futureYd0./Kprimed + (1 - P.delta) ; 
futurePHIdd =  P.alpha*futureYdd./Kprimed + (1 - P.delta).*futurelambdaDd ;

currentPHI0 =  P.alpha*currentY./currentK + (1 - P.delta) ;  % R^K(t)
currentPHId =  P.alpha*currentYd./currentK + (1 - P.delta).*currentlambdaD ;
    
% future tax rate in disaster
futureTauK0d = P.omega(1)*(Bprime+P.g)./(futurePHI0d.*Kprime );
futureTauC0d = P.omega(2)*(Bprime+P.g)./futureC0d;
futureTauG0d = P.omega(3)*(Bprime+P.g)./Bprime;
futureTauT0d = P.omega(4)*(Bprime+P.g); 
futureTauKdd = P.omega(1)*(Bprimed+P.g)./(futurePHIdd.*Kprimed ); 
futureTauCdd = P.omega(2)*(Bprimed+P.g)./futureCdd; 
futureTauGdd = P.omega(3)*(Bprimed+P.g)./Bprimed; 
futureTauGdd( ~isfinite(futureTauGdd) ) = 0;
futureTauTdd = P.omega(4)*(Bprimed+P.g); 

currentTauK = P.omega(1)*(currentB+P.g)./(currentPHId.*currentK );
currentTauG = P.omega(3)*(currentB+P.g)./currentB;


xdis0 = zeros(ncheb,ncheb,Neps); % given no disaster in t 
xdisd = zeros(ncheb,ncheb,Neps); % given disaster in t 
xdis0 = 1 - ((futureTauK0d < 1).*(futureTauG0d < 1));
xdisd = 1 - ((futureTauKdd < 1).*(futureTauGdd < 1));
futureTauK0d = min(futureTauK0d, 1); 
futureTauG0d = min(futureTauG0d, 1); 
futureTauKdd = min(futureTauKdd, 1); 
futureTauGdd = min(futureTauGdd, 1); 

% disaster probability at t+1
% probD0*exp(probD1*b^G)
%p0 = min(max(P.probD0*exp(P.probD1*Bprime) + xdis0, 0), 1); % given no disaster in t  
%pd = min(max(P.probD0*exp(P.probD1*Bprimed) + xdisd, 0), 1); % given disaster in t    
p0 = min(max( 1/(1+(1/P.probD0-1)*exp(-P.probD1*Bprime))  + xdis0, 0), 1); % given no disaster in t  
pd = min(max( 1/(1+(1/P.probD0-1)*exp(-P.probD1*Bprimed)) + xdisd, 0), 1); % given disaster in t    
    
% t+1 term in M_{t+1} excluding the term of beta and mu&eps_{t+1}
futureMU00 = futureC00.^(P.nu*(1-P.gamma)-1).*(1-futureN00).^((1-P.nu)*(1-P.gamma)) ;  %% term of (t+1) in M_{t+1} w/o disaster
futureMU0d = 1./(1+futureTauC0d).*futureC0d.^(P.nu*(1-P.gamma)-1).*(1-futureN0d).^((1-P.nu)*(1-P.gamma)) ;  %% term of (t+1) in M_{t+1} w/ disaster
futureMUd0 = futureCd0.^(P.nu*(1-P.gamma)-1).*(1-futureNd0).^((1-P.nu)*(1-P.gamma)) ;  
futureMUdd = 1./(1+futureTauCdd).*futureCdd.^(P.nu*(1-P.gamma)-1).*(1-futureNdd).^((1-P.nu)*(1-P.gamma)) ;  


% Et( ...esp * u_{t+1}^... )
Term_EU00 = futureU00 ;
Term_EU0d = futureU0d ;
Term_EUd0 = futureUd0 ;
Term_EUdd = futureUdd ;
% integral over eps and disaster prob 
Term_EU = squeeze(sum(Term_EU00.*DF.*(1-p0),3)) + squeeze(sum(Term_EU0d.*DF.*p0,3));
Term_EUd = squeeze(sum(Term_EUd0.*DF.*(1-pd),3)) + squeeze(sum(Term_EUdd.*DF.*pd,3));

% t term in M_{t+1}
intermMU = (currentC).^(P.nu*(1-P.gamma)-1).*(1-currentN).^((1-P.nu)*(1-P.gamma));
intermMUd = 1./(1+currentTauCd).*(currentCd).^(P.nu*(1-P.gamma)-1).*(1-currentNd).^((1-P.nu)*(1-P.gamma));
    
% t+1 term  in M_{t+1} when investing K for banks
Term_K00 = futureMU00.*futurePHI00;
Term_K0d = futureMU0d.*(1-futureTauK0d).*futurePHI0d;
Term_Kd0 = futureMUd0.*futurePHId0;
Term_Kdd = futureMUdd.*(1-futureTauKdd).*futurePHIdd;
% integral over eps and disaster prob 
Term_K = squeeze(sum(Term_K00.*DF2.*(1-p0),3)) + squeeze(sum(Term_K0d.*DF2.*p0,3));
Term_Kd = squeeze(sum(Term_Kd0.*DF2.*(1-pd),3)) + squeeze(sum(Term_Kdd.*DF2.*pd,3));

% t+1 term  in M_{t+1} when investing BG for banks
Term_QG00 = futureMU00 ;
Term_QG0d = futureMU0d.*(1-futureTauG0d) ;
Term_QGd0 = futureMUd0 ;
Term_QGdd = futureMUdd.*(1-futureTauGdd) ;
% integral over eps and disaster prob 
Term_QG = squeeze(sum(Term_QG00.*DF2.*(1-p0),3)) + squeeze(sum(Term_QG0d.*DF2.*p0,3));
Term_QGd = squeeze(sum(Term_QGd0.*DF2.*(1-pd),3)) + squeeze(sum(Term_QGdd.*DF2.*pd,3));

%%% second FOC: arbitrage condition between K & BG for banks
part2 = Term_K - 1./currentQG.*Term_QG;
part2d = Term_Kd - 1./currentQGd.*Term_QGd;
part22 = reshape(part2,ncheb*ncheb,1) ;
part22d = reshape(part2d,ncheb*ncheb,1) ;

%%%%%%%%%%%%%%%%%%%
%%% Third FOC %%%
%%%%%%%%%%%%%%%%%%%
% Return on deposit
futureRD00 = ( futurePHI00.*Kprime + Bprime )./( Kprime+currentQG.*Bprime );
futureRD0d = ( (1-futureTauK0d).*futurePHI0d.*Kprime + (1-futureTauG0d).*Bprime )./( Kprime+currentQG.*Bprime );
futureRDd0 = ( futurePHId0.*Kprimed + Bprimed )./( Kprimed+currentQGd.*Bprimed );
futureRDdd  = ( (1-futureTauKdd).*futurePHIdd.*Kprimed + (1-futureTauGdd).*Bprimed )./( Kprimed+currentQGd.*Bprimed );
%The fraction of average real return at crisis
%xi =  futureRD0d./futureRD00 ;
%xid = futureRDdd./futureRDd0 ;
%The ratio of loss to assets at disaster
xi = ( currentPHI0.*currentK - (1-currentTauK).*currentPHId.*currentK + currentTauG.*currentB )./( currentPHI0.*currentK + currentB );
%xi = ( currentPHI0 - (1-currentTauK).*currentPHId  )./currentPHI0;
xi = max(min(xi, 0.6), 0.0);

% t+1 term  in M_{t+1} when deposit for HH
Term_D00 = futureMU00.*futureRD00;
Term_D0d = futureMU0d.*futureRD0d;
Term_Dd0 = futureMUd0.*futureRDd0;
Term_Ddd = futureMUdd.*futureRDdd;
% integral over eps and disaster prob 
Term_D = squeeze(sum(Term_D00.*DF2.*(1-p0),3)) + squeeze(sum(Term_D0d.*DF2.*p0,3));
Term_Dd = squeeze(sum(Term_Dd0.*DF2.*(1-pd),3)) + squeeze(sum(Term_Ddd.*DF2.*pd,3));

%%% FOC: for deposit
part3 = intermMU./phiprimetoday - P.beta*Term_D ;
part3d = intermMUd./phiprimetodayd - P.beta*Term_Dd ;
part33 = reshape(part3,ncheb*ncheb,1) ;
part33d = reshape(part3d,ncheb*ncheb,1) ;

%%%%%%%%%%%%%%%%%%%
%%% fourth FOC %%%
%%%%%%%%%%%%%%%%%%%

% utility
part4 = currentU - ( (1-P.beta)*currentC.^(P.nu*(1-P.gamma)).*(1-currentN).^((1-P.nu)*(1-P.gamma)) + P.beta*Term_EU );
part44 = reshape(part4,ncheb*ncheb,1) ;
part4d = currentUd - ( (1-P.beta)*currentCd.^(P.nu*(1-P.gamma)).*(1-currentNd).^((1-P.nu)*(1-P.gamma)) + P.beta*Term_EUd );
part44d = reshape(part4d,ncheb*ncheb,1) ;


%%%%%%%%%%%%%%%%%%%
%%% fifth FOC %%%
%%%%%%%%%%%%%%%%%%%

% lambda
part5 = currentlambda - (1 - P.lambdaY0 - P.lambdaY1*log(1+xi)).^(1/P.alpha);
part55 = reshape(part5,ncheb*ncheb,1) ;


%if P.nonnegativity==1  % investment has to be positive
%    % if investment is negative or zero, this equality is not satisfied.
%    part44 = (currentI-currentI0).*(currentI-currentI0)*1e-1 + part44;
%    part44d = (currentId-currentId0).*(currentId-currentId0)*1e-1 + part44d;
%end

%%% Stacking.
f = [ part11 ; part11d; part22; part22d; part33 ; part33d; part44; part44d; part55];

%%
%%% Price QD  such that E(M) = 1/QD %%%
% integral over eps and disaster prob 
Term_QD = squeeze(sum(futureMU00.*DF2.*(1-p0),3)) + squeeze(sum(futureMU0d.*DF2.*p0,3));
Term_QDd = squeeze(sum(futureMUd0.*DF2.*(1-pd),3)) + squeeze(sum(futureMUdd.*DF2.*pd,3));

currentQD  = P.beta*Term_QD./(intermMU./phiprimetoday); 
currentQDd = P.beta*Term_QDd./(intermMUd./phiprimetodayd); 

%%% Check if HH does not directly hold BG %%%
CheckPos = intermMU./phiprimetoday - P.beta./currentQG.*Term_QG;
CheckPosd = intermMUd./phiprimetodayd - P.beta./currentQGd.*Term_QGd;

%% expected return
futureRD0 = squeeze(sum(futureRD00.*DF2.*(1-p0),3)) + squeeze(sum(futureRD0d.*DF2.*p0,3));
futureRDd = squeeze(sum(futureRDd0.*DF2.*(1-pd),3)) + squeeze(sum(futureRDdd.*DF2.*pd,3));
futurePHI0 = squeeze(sum(futurePHI00.*DF2.*(1-p0),3)) + squeeze(sum(futurePHI0d.*DF2.*p0,3));
futurePHId = squeeze(sum(futurePHId0.*DF2.*(1-pd),3)) + squeeze(sum(futurePHIdd.*DF2.*pd,3));
futureRG0 = 1./currentQG.*squeeze(sum(DF2.*(1-p0),3)) + 1./currentQG.*squeeze(sum((1-futureTauG0d).*DF2.*p0,3));
futureRGd = 1./currentQGd.*squeeze(sum(DF2.*(1-pd),3)) + 1./currentQGd.*squeeze(sum((1-futureTauGdd).*DF2.*pd,3));

%% Expected M_{t+1} given no z shock and no crisis in t
futureM0 = P.beta*futureMU00(:,:,floor((P.Neps+1)/2))./( intermMU./phiprimetoday );
futureMd = P.beta*futureMU0d(:,:,floor((P.Neps+1)/2))./( intermMU./phiprimetoday );

%%
V.currentQD = currentQD;
V.currentQDd = currentQDd;
V.xi = xi;
V.futureRD00 = futureRD00;
V.futureRDd0 = futureRDd0;
V.futureRD0d = futureRD0d;
V.futureRDdd = futureRDdd;
V.futurePHI00 = futurePHI00;
V.futurePHId0 = futurePHId0;
V.futurePHI0d = futurePHI0d;
V.futurePHIdd = futurePHIdd;
V.futureTauK0d = futureTauK0d;
V.futureTauKdd = futureTauKdd;
V.futurelambda0 = futurelambda0;
V.futurelambdad = futurelambdad;
V.futureTauG0d = futureTauG0d;
V.futureTauGdd = futureTauGdd;
V.futureRD0 = futureRD0;
V.futureRDd = futureRDd;
V.futurePHI0 = futurePHI0;
V.futurePHId = futurePHId;
V.futureRG0 = futureRG0;
V.futureRGd = futureRGd;
V.futureM0 = futureM0;
V.futureMd = futureMd;

end
