
function [f V] = function_main_EZnew_ctax(coeffs_all, boundREAL1, boundREAL2, nodes_k, nodes_b, bound1, bound2, P, DF, DF2)


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% this function evalutes the errors in the FOCs
%%% then we try to set this function equal to zero
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

ncheb = P.ncheb;
Neps = P.Neps;

%P.normal_tax == 1

coeffs_N   = coeffs_all(1:ncheb*ncheb) ;
coeffs_C   = coeffs_all(1*ncheb*ncheb+1:2*ncheb*ncheb) ;
coeffs_U   = coeffs_all(2*ncheb*ncheb+1:3*ncheb*ncheb) ; 
coeffs_QG   = coeffs_all(3*ncheb*ncheb+1:4*ncheb*ncheb) ; % government bond price

coeffs_N   = reshape(coeffs_N,[ncheb ncheb]) ;
coeffs_C   = reshape(coeffs_C,[ncheb ncheb]) ;
coeffs_U   = reshape(coeffs_U,[ncheb ncheb]) ;
coeffs_QG   = reshape(coeffs_QG,[ncheb ncheb]) ;
    
%%% construct values of N,C,L, etc. at chebychev nodes

currentN   = zeros(ncheb,ncheb);
currentC   = zeros(ncheb,ncheb);
currentU   = zeros(ncheb,ncheb);
currentK   = zeros(ncheb,ncheb);
currentB   = zeros(ncheb,ncheb);
currentQG   = zeros(ncheb,ncheb);

for i=1:ncheb
    for j=1:ncheb
        currentK(i,j)   = nodes_k(i) ;
        currentB(i,j)   = nodes_b(j) ;
        currentN(i,j)   = chebeval2(coeffs_N,nodes_k(i),nodes_b(j),bound1,bound2,ncheb) ;
        currentC(i,j)   = chebeval2(coeffs_C,nodes_k(i),nodes_b(j),bound1,bound2,ncheb) ;
        currentU(i,j)   = chebeval2(coeffs_U,nodes_k(i),nodes_b(j),bound1,bound2,ncheb) ;
        currentQG(i,j)   = chebeval2(coeffs_QG,nodes_k(i),nodes_b(j),bound1,bound2,ncheb) ; 
    end
end

currentN0 = currentN;
currentC0 = currentC;
if P.nonnegativity==1
    currentN  = max(min(currentN,.999),1e-8) ;
    currentC  = max(currentC,1e-8) ;
end

currentW = (1-P.alpha).*currentK.^P.alpha.*currentN.^(-P.alpha) ;
currentY  = currentK.^P.alpha.*currentN.^(1-P.alpha) ;
currentI = currentY - currentC ;
currentI0 = currentI;
if P.nonnegativity==1  % investment has to be positive
    currentI = max(1e-8, currentI);
    currentC = currentY - currentI;
end

%%% for the other FOCs, need to know future values:
phiADJ = P.a_0 + P.a_1./(1-P.eta).*(currentI./currentK).^(1-P.eta); % the last part of this can create non-real number
phiprimetoday = P.a_1.*(currentI./currentK).^(-P.eta);

%%%%%%%%%%%%%%%%%%%%%% capital next period, (d for when disaster hits today,) if today in (ncheb,ncheb) and get tomorrow eps
%%% gov bond next period, (d for when disaster hits today,) if today in (ncheb,ncheb) and get tomorrow eps
Kprime = zeros(ncheb,ncheb,Neps);
Bprime = zeros(ncheb,ncheb,Neps);
for i=1:Neps
    Kprime(:,:,i) =  max(boundREAL1(1),min( ((1-P.delta).*currentK+phiADJ.*currentK)/(exp(P.mu+P.stdtfp*P.grideps(i))),boundREAL1(2)));
    % omegaC so that b' becomes target of b (Targetb)
        omegaC1 = 1 - P.Targetb./(currentB + P.g).*currentQG.*exp(P.mu);
        TauC = omegaC1.*(currentB + P.g)./currentC;
        TauC = (TauC > P.MaxTauC).*P.MaxTauC + (TauC < 0).*0 ...
            + (1-(TauC > P.MaxTauC)).*(1-(TauC < 0)).*TauC;     
        Bprime(:,:,i) = ( currentB + P.g - TauC.*currentC )./currentQG/exp(P.mu+P.stdtfp*P.grideps(i)) ;
        Bprime(:,:,i) =  max(boundREAL2(1),min( Bprime(:,:,i) , boundREAL2(2)));
end

%%% 1st FOC: error in FOC for labor:
part1 = currentW.*(1-currentN)-(1-P.nu)/P.nu*currentC.*(1+TauC) ;
part1 = part1 + (currentN-currentN0).*(currentN-currentN0) + (currentC-currentC0).*(currentC-currentC0);
part11 = reshape(part1,ncheb*ncheb,1) ;

%%%%%%%%%%%%%%%%%%%
%%% Second FOC %%%

futureN00 = chebeval2(coeffs_N,Kprime,Bprime,bound1,bound2,ncheb) ; %no disaster in t & t+1
futureC00 = chebeval2(coeffs_C,Kprime,Bprime,bound1,bound2,ncheb) ;
futureU00 = chebeval2(coeffs_U,Kprime,Bprime,bound1,bound2,ncheb) ;

if P.nonnegativity==1
    futureU00 = max(futureU00,1e-13) ;
    futureN00  = max(min(futureN00,.999),1e-6) ;
end

futureY00 = Kprime.^P.alpha.*futureN00.^(1-P.alpha) ;
if P.nonnegativity==1
    futureC00 = min(futureY00*.999,max(futureC00,1e-6)) ;  % investment has to be above zero
end
futureI00 = futureY00 - futureC00 ;

futurePHI00 =  P.alpha*futureY00./Kprime + (1 - P.delta) ;  % R^K(t+1)

currentPHI0 =  P.alpha*currentY./currentK + (1 - P.delta) ;  % R^K(t)
       
futureQG = chebeval2(coeffs_QG,Kprime,Bprime,bound1,bound2,ncheb);
futureomegaC = 1 - P.Targetb./(Bprime + P.g).*futureQG.*exp(P.mu);
futureTauC = futureomegaC.*(Bprime + P.g)./futureC00;
futureTauC = (futureTauC > P.MaxTauC).*P.MaxTauC  ...
        + (futureTauC < 0).*0 ...
        + (1-(futureTauC > P.MaxTauC)).*(1-(futureTauC < 0)).*futureTauC;  
        
% t+1 term in M_{t+1} excluding the term of beta and mu&eps_{t+1}
futureMU00 = 1./(1+futureTauC).*futureC00.^(P.nu*(1-P.gamma)-1).*(1-futureN00).^((1-P.nu)*(1-P.gamma)) ;  %% term of (t+1) in M_{t+1} w/o disaster

% Et( ...esp * u_{t+1}^... )
Term_EU00 = futureU00 ;

% integral over eps and disaster prob 
Term_EU = squeeze(sum(Term_EU00.*DF,3)) ;

% t term in M_{t+1}
intermMU = 1./(1+TauC).*(currentC).^(P.nu*(1-P.gamma)-1).*(1-currentN).^((1-P.nu)*(1-P.gamma));
    
% t+1 term  in M_{t+1} when investing K for banks
Term_K00 = futureMU00.*futurePHI00;

% integral over eps and disaster prob 
Term_K = squeeze(sum(Term_K00.*DF2,3)) ;

% t+1 term  in M_{t+1} when investing BG for banks
Term_QG00 = futureMU00 ;
Term_QG = squeeze(sum(Term_QG00.*DF2,3));

%%% second FOC: arbitrage condition between K & BG for banks
part2 = Term_K - 1./currentQG.*Term_QG;
part22 = reshape(part2,ncheb*ncheb,1) ;

%%%%%%%%%%%%%%%%%%%
%%% Third FOC %%%
%%%%%%%%%%%%%%%%%%%
% Return on deposit
futureRD00 = ( futurePHI00.*Kprime + Bprime )./( Kprime+currentQG.*Bprime );

% t+1 term  in M_{t+1} when deposit for HH
Term_D00 = futureMU00.*futureRD00;
% integral over eps and disaster prob 
Term_D = squeeze(sum(Term_D00.*DF2,3));

%%% FOC: for deposit
part3 = intermMU./phiprimetoday - P.beta*Term_D ;
part33 = reshape(part3,ncheb*ncheb,1) ;

%%%%%%%%%%%%%%%%%%%
%%% fourth FOC %%%
%%%%%%%%%%%%%%%%%%%

% utility
part4 = currentU - ( (1-P.beta)*currentC.^(P.nu*(1-P.gamma)).*(1-currentN).^((1-P.nu)*(1-P.gamma)) + P.beta*Term_EU );
part44 = reshape(part4,ncheb*ncheb,1) ;


f = [ part11 ; part22;  part33 ; part44];

%%
%%% Price QD  such that E(M) = 1/QD %%%
% integral over eps and disaster prob 
Term_QD = squeeze(sum(futureMU00.*DF2,3));

currentQD  = P.beta*Term_QD./(intermMU./phiprimetoday); 

%%% Check if HH does not directly hold BG %%%
CheckPos = intermMU./phiprimetoday - P.beta./currentQG.*Term_QG;

%% expected return
futureRD0 = squeeze(sum(futureRD00.*DF2,3));
futurePHI0 = squeeze(sum(futurePHI00.*DF2,3));
futureRG0 = 1./currentQG.*squeeze(sum(DF2,3));


%% Expected M_{t+1} given no z shock and no crisis in t
futureM0 = P.beta*futureMU00(:,:,floor((P.Neps+1)/2))./( intermMU./phiprimetoday );

%%
V.currentQD = currentQD;
V.currentQDd = currentQD;
V.xi = zeros(ncheb, ncheb);
V.futureRD00 = futureRD00;
V.futureRDd0 = futureRD00;
V.futureRD0d = futureRD00;
V.futureRDdd = futureRD00;
V.futurePHI00 = futurePHI00;
V.futurePHId0 = futurePHI00;
V.futurePHI0d = futurePHI00;
V.futurePHIdd = futurePHI00;
V.futureTauK0d = 0;
V.futureTauKdd = 0;
V.futurelambda0 = 1;
V.futurelambdad = 1;
V.futureTauG0d = 0;
V.futureTauGdd = 0;
V.futureRD0 = futureRD0;
V.futureRDd = futureRD0;
V.futurePHI0 = futurePHI0;
V.futurePHId = futurePHI0;
V.futureRG0 = futureRG0;
V.futureRGd = futureRG0;
V.futureTauC = futureTauC;
V.TauC = TauC;
V.futureM0 = futureM0;
V.futureMd = futureM0;


