


load ..\..\data\data_japan;
Y_tab = Y_tab(:,1:end-2);
C_tab = C_tab(:,1:end-2);
I_tab = I_tab(:,1:end-2);
B_Y_tab  = B_Y_tab(:,1:end-2);

spread_data = csvread('..\..\data\spread_JPN.csv',1,0);

% save data
data.dY = Y_tab(2,2:end) - Y_tab(2,1:end-1);
data.dC = C_tab(2,2:end) - C_tab(2,1:end-1);
data.dI = I_tab(2,2:end) - I_tab(2,1:end-1);
data.bondspread = spread_data(:,2)'/100;
data.creditspread = spread_data(:,3)'/100;
data.depositspread = spread_data(:,4)'/100;
data.CDSspread = spread_data(:,5)'/100;

data.mean.net_B_Y = nanmean( B_Y_tab(2,:) );
data.mean.gross_B_Y = nanmean( B_Y_tab(3,:) );
data.mean.creditspread = nanmean( data.creditspread );
data.mean.bondspread = nanmean( data.bondspread );
data.mean.depositspread = nanmean( data.depositspread );
data.mean.CY = exp( nanmean( C_tab(2,:) - Y_tab(2,:) ) );
data.mean.IY = exp( nanmean( I_tab(2,:) - Y_tab(2,:) ) );

data.mean.CDS1 = mean( data.CDSspread(29:32) ); % mean from 2003 to 2006

%{
% CDS spread to crisis probability
P.maturity = 5;
options = optimset('Display', 'Off', 'MaxFunEvals',1.e6, 'MaxIter', 1.e4, 'Algorithm', 'levenberg-marquardt');


omegaG = 0.0760;
omegaK = 0.2015

rec = 1-omegaG;
data.prob = NaN*ones(1,28);
for jj=29:45
    ll = fsolve(@(x) cds(x,P,rec,data.CDSspread(jj)), 0.1, options);
    data.prob = [data.prob 1-exp(-ll)]; % annual crisis probability
end
data.mean.prob1 = mean( data.prob(29:32) ); % mean from 2003 to 2006
data.mean.prob2 = mean( data.prob(43:end) ); % mean from 2017 to 2019

rec = 1-omegaG*2;
data.probrec1 = NaN*ones(1,28);
for jj=29:45
    ll = fsolve(@(x) cds(x,P,rec,data.CDSspread(jj)), 0.1, options);
    data.probrec1 = [data.probrec1 1-exp(-ll)]; % annual crisis probability
end
data.mean.probrec11 = mean( data.probrec1(29:32) ); % mean from 2003 to 2006
data.mean.probrec12 = mean( data.probrec1(43:end) ); % mean from 2017 to 2019

rec2 = 1-omegaG*2-omegaK;
data.probrec2 = NaN*ones(1,28);
for jj=29:45
    ll = fsolve(@(x) cds(x,P,rec2,data.CDSspread(jj)), 0.1, options);
    data.probrec2 = [data.probrec2 1-exp(-ll)]; % annual crisis probability
end
data.mean.probrec21 = mean( data.probrec2(29:32) ); % mean from 2003 to 2006
data.mean.probrec22 = mean( data.probrec2(43:end) ); % mean from 2017 to 2019
%}

data.sigma.y = nanstd( data.dY );
data.sigma.c = nanstd( data.dC );
data.sigma.i = nanstd( data.dI );
data.sigma.creditspread = nanstd( data.creditspread );
data.sigma.bondspread = nanstd( data.bondspread );
data.sigma.depositspread = nanstd( data.depositspread );

data.cor.dyb = corrcoef(data.dY', B_Y_tab(2,1:end-1)', 'rows','complete'); % correlation between dY and B^G/Y(t-1)
data.cor.dib = corrcoef(data.dI', B_Y_tab(2,1:end-1)', 'rows','complete'); % correlation between dI and B^G/Y(t-1)
data.cor.yb = corrcoef(Y_tab(3,:), B_Y_tab(2,:)', 'rows','complete'); % correlation between Y and B^G/Y(t-1)
data.cor.ib = corrcoef(I_tab(3,:), B_Y_tab(2,:)', 'rows','complete'); % correlation between I and B^G/Y(t-1)

data.cor.dycreditspread = corrcoef(data.dY', data.creditspread(2:end)', 'rows','complete'); 
data.cor.dybondspread = corrcoef(data.dY', data.bondspread(2:end)', 'rows','complete'); 
data.cor.dydepositspread = corrcoef(data.dY', data.depositspread(2:end)', 'rows','complete'); 
data.cor.dicreditspread = corrcoef(data.dI', data.creditspread(2:end)', 'rows','complete'); 
data.cor.dibondspread = corrcoef(data.dI', data.bondspread(2:end)', 'rows','complete'); 
data.cor.didepositspread = corrcoef(data.dI', data.depositspread(2:end)', 'rows','complete'); 
data.cor.icreditspread = corrcoef(I_tab(3,:), data.creditspread', 'rows','complete'); 
data.cor.ibondspread = corrcoef(I_tab(3,:), data.bondspread', 'rows','complete'); 
data.cor.idepositspread = corrcoef(I_tab(3,:), data.depositspread', 'rows','complete'); 


function cdsspread = cds(l,P,rec,data)

    r = 1/(P.beta*exp((P.nu*(1-P.gamma)-1)*P.mu)) - 1;
    aaa = exp(-1/2*(r+l));
    cdsspread = 2*(1-rec)*l/(r+l)*(1-aaa)/aaa - data;
end